<?php
if (!class_exists('Newsever_Posts_Slider')) :
    /**
     * Adds Newsever_Posts_Slider widget.
     */
    class Newsever_Posts_Slider extends AFthemes_Widget_Base
    {
        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $this->text_fields = array('newsever-posts-slider-title', 'newsever-excerpt-length', 'newsever-posts-slider-number');
            $this->select_fields = array('newsever-select-category', 'newsever-show-excerpt','newsever-select-background', 'newsever-select-background-type');

            $widget_ops = array(
                'classname' => 'newsever_posts_slider_widget aft-widget',
                'description' => __('Displays posts slider from selected category.', 'newsever'),
                'customize_selective_refresh' => false,
            );

            parent::__construct('newsever_posts_slider', __('AFTN Posts Slider', 'newsever'), $widget_ops);
        }

        /**
         * Front-end display of widget.
         *
         * @see WP_Widget::widget()
         *
         * @param array $args Widget arguments.
         * @param array $instance Saved values from database.
         */

        public function widget($args, $instance)
        {
            $instance = parent::newsever_sanitize_data($instance, $instance);


            /** This filter is documented in wp-includes/default-widgets.php */
            $title = apply_filters('widget_title', $instance['newsever-posts-slider-title'], $instance, $this->id_base);
            $category = isset($instance['newsever-select-category']) ? $instance['newsever-select-category'] : 0;
            $number_of_posts = isset($instance['newsever-posts-slider-number']) ? $instance['newsever-posts-slider-number'] : 5;
            $background = isset($instance['newsever-select-background']) ? $instance['newsever-select-background'] : 'default';

            $background_type = isset($instance['newsever-select-background-type']) ? $instance['newsever-select-background-type'] : 'solid-background';

            $background = $background . ' ' . $background_type;


            if ( $instance['newsever-select-background'] || $instance['newsever-select-background-type']) {
                $args['before_widget']= newsever_update_widget_before($args,$background,'aft-widget');
            }
            // open the widget container
            echo $args['before_widget'];
            ?>
            <?php if (!empty($title)): ?>
            <div class="em-title-subtitle-wrap">
                <?php if (!empty($title)): ?>
                    <h4 class="widget-title header-after1">
                        <span class="header-after">
                            <?php echo esc_html($title); ?>
                            </span>
                    </h4>
                <?php endif; ?>
            </div>
        <?php endif; ?>
            <?php

            $all_posts = newsever_get_posts(5, $category);
            ?>
            <div class="widget-block widget-wrapper">
            <div class="posts-slider banner-slider-2  af-post-slider af-widget-carousel slick-wrapper">
                    <?php
                    if ($all_posts->have_posts()) :
                        while ($all_posts->have_posts()) : $all_posts->the_post();
                            global $post;
                            $thumbnail_size = 'large';
                            ?>
                            <div class="slick-item">
                                <div class="big-grid ">
                                    <div class="read-single pos-rel">
                                        <div class="read-img pos-rel read-bg-img">
                                            <a class="aft-slide-items" href="<?php the_permalink(); ?>">
                                            <?php if ( has_post_thumbnail() ):
                                                the_post_thumbnail($thumbnail_size);
                                            endif;
                                            ?>
                                            </a>
                                            <div class="min-read-post-format">
                                                <?php echo newsever_post_format($post->ID); ?>
                                                <span class="min-read-item">
                                                <?php newsever_count_content_words($post->ID); ?>
                                            </span>
                                            </div>
                                        </div>
                                        <div class="read-details">
                                            <div class="read-categories af-category-inside-img">

                                                <?php newsever_post_categories(); ?>
                                            </div>


                                            <div class="read-title">
                                                <h4>
                                                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                                </h4>
                                            </div>

                                            <div class="entry-meta">
                                                <?php newsever_post_item_meta(); ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endwhile;
                    endif;
                    wp_reset_postdata();
                    ?>
            </div>
            </div>

            <?php
            // close the widget container
            echo $args['after_widget'];
        }

        /**
         * Back-end widget form.
         *
         * @see WP_Widget::form()
         *
         * @param array $instance Previously saved values from database.
         */
        public function form($instance)
        {
            $this->form_instance = $instance;
            $options = array(
                'true' => __('Yes', 'newsever'),
                'false' => __('No', 'newsever')

            );
    
            $background = array(
                'default' => __('Default', 'newsever'),
                'dim' => __('Dim', 'newsever'),
                'dark' => __('Alternative', 'newsever'),
    
            );




            $categories = newsever_get_terms();
            if (isset($categories) && !empty($categories)) {
                // generate the text input for the title of the widget. Note that the first parameter matches text_fields array entry
                echo parent::newsever_generate_text_input('newsever-posts-slider-title', __('Title', 'newsever'), 'Posts Slider');

                echo parent::newsever_generate_select_options('newsever-select-category', __('Select category', 'newsever'), $categories);

                echo parent::newsever_generate_select_options('newsever-select-background', __('Select Background', 'newsever'), $background);

            }
        }
    }
endif;